about summary refs log tree commit diff
path: root/pkgs/development/haskell-modules/make-package-set.nix
diff options
context:
space:
mode:
authorPeter Simons <simons@cryp.to>2021-01-19 19:26:01 +0100
committerPeter Simons <simons@cryp.to>2021-01-22 20:34:21 +0100
commitc3792f6cddc71ba348e018406f125503d088c405 (patch)
tree89c5ec06c46db083967bec35855382c3c8437541 /pkgs/development/haskell-modules/make-package-set.nix
parent71e660bb8d57e7586dce1df2c02e46b64a9c3b11 (diff)
downloadnixlib-c3792f6cddc71ba348e018406f125503d088c405.tar
nixlib-c3792f6cddc71ba348e018406f125503d088c405.tar.gz
nixlib-c3792f6cddc71ba348e018406f125503d088c405.tar.bz2
nixlib-c3792f6cddc71ba348e018406f125503d088c405.tar.lz
nixlib-c3792f6cddc71ba348e018406f125503d088c405.tar.xz
nixlib-c3792f6cddc71ba348e018406f125503d088c405.tar.zst
nixlib-c3792f6cddc71ba348e018406f125503d088c405.zip
Consistently use 'lib' instead of 'stdenv.lib' in the Haskell infrastructure.
Part of https://github.com/NixOS/nixpkgs/issues/108938.
Diffstat (limited to 'pkgs/development/haskell-modules/make-package-set.nix')
-rw-r--r--pkgs/development/haskell-modules/make-package-set.nix10
1 files changed, 7 insertions, 3 deletions
diff --git a/pkgs/development/haskell-modules/make-package-set.nix b/pkgs/development/haskell-modules/make-package-set.nix
index 4ae3f0b2427f..91937b88eaff 100644
--- a/pkgs/development/haskell-modules/make-package-set.nix
+++ b/pkgs/development/haskell-modules/make-package-set.nix
@@ -11,9 +11,13 @@
 , # package-set used for non-haskell dependencies (all of nixpkgs)
   pkgs
 
-, # stdenv to use for building haskell packages
+, # stdenv provides our build and host platforms
   stdenv
 
+, # this module provides the list of known licenses and maintainers
+  lib
+
+  # needed for overrideCabal & packageSourceOverrides
 , haskellLib
 
 , # hashes for downloading Hackage packages
@@ -22,7 +26,7 @@
 , # compiler to use
   ghc
 
-, # A function that takes `{ pkgs, stdenv, callPackage }` as the first arg and
+, # A function that takes `{ pkgs, lib, callPackage }` as the first arg and
   # `self` as second, and returns a set of haskell packages
   package-set
 
@@ -169,7 +173,7 @@ let
       };
     });
 
-in package-set { inherit pkgs stdenv callPackage; } self // {
+in package-set { inherit pkgs lib callPackage; } self // {
 
     inherit mkDerivation callPackage haskellSrc2nix hackage2nix buildHaskellPackages;